@@ -1,10 +1,23 @@
 #!/usr/bin/env python3
+"""
+Common steps part with definition of precoded decorator steps for behave usage.
+"""
+
 from time import sleep
 import subprocess
-from behave import step
-from dogtail.rawinput import typeText, pressKey, keyCombo, absoluteMotion, click
-from qecore.utility import get_application, get_application_root, run
-from qecore.get_node import GetNode, get_center
+
+from behave import step  # pylint: disable=no-name-in-module
+
+from dogtail.rawinput import (  # pylint: disable=import-error
+    click,
+    keyCombo,
+    pressKey,
+    typeText,
+    absoluteMotion,
+)
+
+from qecore.utility import get_application, get_center
+from qecore.get_node import GetNode
 from qecore.step_matcher import use_step_matcher
 
 __author__ = """
@@ -16,7 +29,7 @@ Bohdan Milar <bmilar@redhat.com>
 # To stop using "qecore" matcher use matcher "parse".
 use_step_matcher("qecore")
 
-"""
+HELP = """
 This allows multiple decorator definitions on one line separated by ' | '
 EXAMPLE:
 This decorator:
@@ -41,83 +54,138 @@ POS_DEC = "".join([' | that is at least "{position_low}" from topleft',
                    ' | that is at most "{position_high}" from topleft'])
 SIZE_POS_DEC = SIZE_DEC + POS_DEC
 
+DESC = ' | with description "{description}"'
+ATTR = ' | that is "{attr}" | is "{attr}"'
+ROOT = ' | in "{a11y_root_name}"'
+TEXT = ' | has text "{text}"'
+
+NOT_ATTR = ' | that is not "{attr}" | is not "{attr}"'
+NOT_TEXT = ' | does not have text "{text}"'
+NOT_DESC = ' | does not have description "{description}"'
+
+START_OPTIONS = ' | via "{start_via}" | via command "{command}" | via command | in "{session}"'
+
+
+@step('{m_btn} click "{name}" "{role_name}"' + DESC + ATTR + ROOT + SIZE_POS_DEC)
+def mouse_click(context, retry=True, expect_positive=True, **kwargs) -> None:
+    """
+    Mouse clicking function to be used by behave feature files.
+    """
 
-@step('{m_btn} click "{name}" "{role_name}" | with description "{description}" | that is "{attr}" | in "{a11y_root_name}"' + SIZE_POS_DEC)
-def mouse_click(context, retry=True, expect_positive=True, **kwargs):
     with GetNode(context, **kwargs, retry=retry, expect_positive=expect_positive) as (data, node):
         node.click(data.m_btn)
 
 
-@step('Mouse over "{name}" "{role_name}" | with description "{description}" | that is "{attr}" | in "{a11y_root_name}"' + SIZE_POS_DEC)
-def mouse_over(context, retry=True, expect_positive=True, **kwargs):
+@step('Mouse over "{name}" "{role_name}"' + DESC + ATTR + ROOT + SIZE_POS_DEC)
+def mouse_over(context, retry=True, expect_positive=True, **kwargs) -> None:
+    """
+    Mouse over function to be used by behave feature files.
+    """
+
     with GetNode(context, **kwargs, retry=retry, expect_positive=expect_positive) as (_, node):
         absoluteMotion(*(get_center(node)))
 
 
-@step('Make an action "{action}" for "{name}" "{role_name}" | with description "{description}" | that is "{attr}" | in "{a11y_root_name}"' + SIZE_POS_DEC)
-def make_action(context, action, retry=True, expect_positive=True, **kwargs):
+@step('Make an action "{action}" for "{name}" "{role_name}"' + DESC + ATTR + ROOT + SIZE_POS_DEC)
+def make_action(context, action, retry=True, expect_positive=True, **kwargs) -> None:
+    """
+    Accessibility action function to be used by behave feature files.
+    """
+
     with GetNode(context, **kwargs, retry=retry, expect_positive=expect_positive) as (_, node):
         node.doActionNamed(action)
 
 
-@step('Item "{name}" "{role_name}" | found | with description "{description}" | is "{attr}" | in "{a11y_root_name}"' + SIZE_POS_DEC)
-def node_attribute(context, retry=True, expect_positive=True, **kwargs):
+@step('Item "{name}" "{role_name}" | found |' + DESC + ATTR + ROOT + SIZE_POS_DEC)
+def node_attribute(context, retry=True, expect_positive=True, **kwargs) -> None:
+    """
+    Verification function to be used by behave feature files.
+    """
+
     with GetNode(context, **kwargs, retry=retry, expect_positive=expect_positive) as (_, node):
         assert node is not None, "Node was not found, it should be!"
 
 
-@step('Item "{name}" "{role_name}" | was not found | with description "{description}" | is not "{attr}" | in "{a11y_root_name}"' + SIZE_POS_DEC)
-def node_not_attribute(context, retry=True, expect_positive=False, **kwargs):
+@step('Item "{name}" "{role_name}" | was not found |' + DESC + NOT_ATTR + ROOT + SIZE_POS_DEC)
+def node_not_attribute(context, retry=True, expect_positive=False, **kwargs) -> None:
+    """
+    Verification function negated to be used by behave feature files.
+    """
+
     with GetNode(context, **kwargs, retry=retry, expect_positive=expect_positive) as (_, node):
         assert node is None, "Node was found, it should not be!"
 
 
-@step('Item "{name}" "{role_name}" | with description "{description}" | has text "{text}" | in "{a11y_root_name}"' + SIZE_POS_DEC)
-def node_with_text(context, text, retry=True, expect_positive=True, **kwargs):
+@step('Item "{name}" "{role_name}"' + DESC + TEXT + ROOT + SIZE_POS_DEC)
+def node_with_text(context, text, retry=True, expect_positive=True, **kwargs) -> None:
+    """
+    Verification function for text attribute to be used by behave feature files.
+    """
+
     with GetNode(context, **kwargs, retry=retry, expect_positive=expect_positive) as (_, node):
         assert text in node.text, "".join((
             f"Found node should have text: {text}\n",
-            f"Instead the node has text: {node.text}"
+            f"Instead the node has text: {node.text}",
         ))
 
 
-@step('Item "{name}" "{role_name}" | with description "{description}" | does not have text "{text}" | in "{a11y_root_name}"' + SIZE_POS_DEC)
-def node_without_text(context, text, retry=True, expect_positive=True, **kwargs):
+@step('Item "{name}" "{role_name}"' + DESC + NOT_TEXT + ROOT + SIZE_POS_DEC)
+def node_without_text(context, text, retry=True, expect_positive=True, **kwargs) -> None:
+    """
+    Verification function for text attribute negated to be used by behave feature files.
+    """
+
     with GetNode(context, **kwargs, retry=retry, expect_positive=expect_positive) as (_, node):
-        assert not text in node.text, "".join((
+        assert text not in node.text, "".join((
             f"Found node should have text: {text}\n",
             f"Node was found with text: {node.text}"
         ))
 
 
-@step('Item "{name}" "{role_name}" | does not have description "{description}" | that is "{attr}" | in "{a11y_root_name}"' + SIZE_POS_DEC)
-def node_without_description(context, description, retry=True, expect_positive=True, **kwargs):
+@step('Item "{name}" "{role_name}"' + NOT_DESC + ATTR + ROOT + SIZE_POS_DEC)
+def node_without_description(context, description, retry=True, expect_positive=True, **kwargs) -> None:
+    """
+    Verification function for description attribute negated to be used by behave feature files.
+    """
+
     with GetNode(context, **kwargs, retry=retry, expect_positive=expect_positive) as (_, node):
-        assert not description in node.description, "".join((
+        assert description not in node.description, "".join((
             f"Found node should not have description: {description}\n",
             f"Instead the node has description: {node.description}"
         ))
 
 
-@step('Wait until "{name}" "{role_name}" | with description "{description}" | is "{attr}" | in "{a11y_root_name}"' + SIZE_POS_DEC)
-def wait_until_attr(context, retry=True, expect_positive=True, **kwargs):
+@step('Wait until "{name}" "{role_name}"' + DESC + ATTR + ROOT + SIZE_POS_DEC)
+def wait_until_attr(context, retry=True, expect_positive=True, **kwargs) -> None:
+    """
+    Wait until accessibility attribute becomes true function to be used by behave feature files.
+    """
+
     with GetNode(context, **kwargs, retry=retry, expect_positive=expect_positive) as (_, node):
         for _ in range(30):
-            if not node.sensitive:
+            if not getattr(node, kwargs.get("attr", "sensitive")):
                 sleep(0.2)
             else:
                 return
 
 
-@step('Wait until "{name}" "{role_name}" | appears | with description "{description}" | in "{a11y_root_name}"' + SIZE_POS_DEC)
-def wait_until_in_root(context, retry=True, expect_positive=True, **kwargs):
+@step('Wait until "{name}" "{role_name}" | appears' + DESC + ROOT + SIZE_POS_DEC)
+def wait_until_in_root(context, retry=True, expect_positive=True, **kwargs) -> None:
+    """
+    Wait until accessibility object appears function to be used by behave feature files.
+    """
+
     with GetNode(context, **kwargs, retry=retry, expect_positive=expect_positive) as (_, node):
         if node is not None:
             return
 
 
-@step('Wait until "{name}" "{role_name}" | disappears | with description "{description}" | is not "{attr}" | in "{a11y_root_name}"' + SIZE_POS_DEC)
-def wait_until_not_in_root(context, retry=False, expect_positive=False, **kwargs):
+@step('Wait until "{name}" "{role_name}" | disappears' + DESC + NOT_ATTR + ROOT + SIZE_POS_DEC)
+def wait_until_not_in_root(context, retry=False, expect_positive=False, **kwargs) -> None:
+    """
+    Wait until accessibility object disappears function to be used by behave feature files.
+    """
+
     for _ in range(10):
         with GetNode(context, **kwargs, retry=retry, expect_positive=expect_positive) as (_, node):
             if node is None:
@@ -128,25 +196,47 @@ def wait_until_not_in_root(context, retry=False, expect_positive=False, **kwargs
         assert node is None, "Node stil found in a11y tree."
 
 
-@step('Start another instance of "{application_name}" | via "{start_via}" | via command "{command}" | via command | in "{session}"')
-def start_another_instance_of_application(context, application_name=None, start_via="command", command=None, session=None, kill=False):
+@step('Start another instance of "{application_name}"' + START_OPTIONS)
+def start_another_instance_of_application(
+    context,
+    application_name=None,
+    start_via="command",
+    command=None,
+    session=None,
+    kill=False
+) -> None:
+    """
+    Start another application instance function to be used by behave feature files.
+    """
+
     start_application(context, application_name, start_via, command, session, kill)
 
 
-@step('Start application "{application_name}" | via "{start_via}" | via command "{command}" | via command | in "{session}"')
-def start_application(context, application_name=None, start_via="command", command=None, session=None, kill=True):
+@step('Start application "{application_name}"' + START_OPTIONS)
+def start_application(
+    context,
+    application_name=None,
+    start_via="command",
+    command=None,
+    session=None,
+    kill=True
+) -> None:
+    """
+    Start application function to be used by behave feature files.
+    """
+
     application = get_application(context, application_name)
     if start_via == "menu":
         try:
             application.start_via_menu(kill=kill)
-        except Exception:
+        except Exception:  # pylint: disable=broad-except
             application.start_via_menu(kill=kill)
     elif start_via == "command":
         try:
             application.start_via_command(command=command, in_session=session, kill=kill)
         except RuntimeError as error:
             assert False, error
-        except Exception:
+        except Exception:  # pylint: disable=broad-except
             application.start_via_command(command=command, in_session=session, kill=kill)
     else:
         raise AssertionError("Only defined options are 'command' and 'menu'.")
@@ -157,22 +247,34 @@ use_step_matcher("parse")
 
 
 @step('Commentary')
-def commentary_step(context):
+def commentary_step(context) -> None:
+    """
+    Commentary step for usage in behave feature files - html-pretty only.
+
+    :param context: Holds contextual information during the running of tests.
+    :type context: <behave.runner.Context>
+    """
+
     # Defined only for html-pretty formatter.
-    # This will return an instance of HTMLFormatter/PrettyHTMLFormatter.
+    # This will return an instance of PrettyHTMLFormatter.
     formatter_instance = getattr(context, "html_formatter", None)
     if formatter_instance is not None and formatter_instance.name == "html-pretty":
         # Get the correct step to override.
         scenario = formatter_instance.current_scenario
         # Current scenario is never none, as this step is being executed.
-        step = scenario.current_step
+        scenario_step = scenario.current_step
+
+        # Override the step, this will prevent the decorator to be generated and only
+        # the text will show.
+        scenario_step.set_commentary(True)
 
-        # Override the step, this will prevent the decorator to be generated and only the text will show.
-        step.set_commentary(True)
-    
 
 @step('Close application "{application_name}" via "{close_via}"')
-def application_in_not_running(context, application_name=None, close_via="gnome panel"):
+def application_in_not_running(context, application_name=None, close_via="gnome panel") -> None:
+    """
+    Close application function to be used by behave feature files.
+    """
+
     application = get_application(context, application_name)
 
     if close_via == "gnome panel":
@@ -190,7 +292,6 @@ def application_in_not_running(context, application_name=None, close_via="gnome
 
         assert False, f"Unable to close '{application_name}' via '{close_via}' in 10 tries."
 
-
     elif close_via == "gnome panel with workaround":
         gnome_panel = context.sandbox.shell.child(application.name, "menu")
         for _ in range(10):
@@ -208,9 +309,9 @@ def application_in_not_running(context, application_name=None, close_via="gnome
 
         assert False, f"Unable to close '{application_name}' via '{close_via}' in 10 tries."
 
-
-    elif (close_via == "application panel menu") or\
-        (close_via == "application menu" and context.sandbox.distribution == "Fedora"):
+    elif (close_via == "application panel menu") or (
+        close_via == "application menu" and context.sandbox.distribution == "Fedora"
+    ):
         application_panel = application.instance.children[0][0]
         for _ in range(10):
             application_panel.click(3)
@@ -225,13 +326,14 @@ def application_in_not_running(context, application_name=None, close_via="gnome
 
         assert False, f"Unable to close '{application_name}' via '{close_via}' in 10 tries."
 
-
     elif close_via in ("application file menu", "application menu"):
         for _ in range(10):
             context.execute_steps(f'* Left click "File" "menu" in "{application.component}"')
             sleep(0.5)
             application_file_menu = application.instance.findChildren(
-                lambda x: ("Close" in x.name or "Quit" in x.name) and x.roleName == "menu item" and x.sensitive
+                lambda x:
+                ("Close" in x.name or "Quit" in x.name)
+                and x.roleName == "menu item" and x.sensitive
             )
             if application_file_menu != []:
                 application_file_menu[0].click()
@@ -240,7 +342,6 @@ def application_in_not_running(context, application_name=None, close_via="gnome
 
         assert False, f"Unable to close '{application_name}' via '{close_via}' in 10 tries."
 
-
     elif close_via == "application toggle menu":
         for _ in range(10):
             context.execute_steps(f'* Left click "Application menu" "toggle button" in "{application.component}"')
@@ -248,19 +349,20 @@ def application_in_not_running(context, application_name=None, close_via="gnome
             try:
                 context.execute_steps(f'* Left click "Quit" "push button" in "{application.component}"')
                 return
-            except Exception:
+            except Exception:  # pylint: disable=broad-except
                 pressKey("Esc")
 
         assert False, f"Unable to close '{application_name}' via '{close_via}' in 10 tries."
 
-
     elif "menu:" in close_via:
         menu_name = None
         menu_item_name = None
         try:
             _, menu_name, menu_item_name = close_via.split(":")
         except Exception as error:
-            raise Exception(f"Expected format of specific close via menu is 'menu:<menu>:<menu_item>\n{error}")
+            raise UserWarning(
+                f"Expected format of specific close via menu is 'menu:<menu>:<menu_item>\n{error}"
+            ) from error
 
         for _ in range(10):
             application.instance.child(menu_name, "menu").click()
@@ -268,20 +370,17 @@ def application_in_not_running(context, application_name=None, close_via="gnome
             try:
                 application.instance.child(menu_item_name, "menu item").click()
                 return
-            except Exception:
+            except Exception:  # pylint: disable=broad-except
                 pressKey("Esc")
 
         assert False, f"Unable to close '{application_name}' via '{close_via}' in 10 tries."
 
-
     elif close_via == "shortcut":
         application.close_via_shortcut()
 
-
     elif close_via == "kill command":
         application.kill_application()
 
-
     else:
         raise AssertionError("".join((
             "Only defined options are:\n",
@@ -291,14 +390,22 @@ def application_in_not_running(context, application_name=None, close_via="gnome
 
 
 @step('Application "{application_name}" is no longer running')
-def application_is_not_running(context, application_name):
+def application_is_not_running(context, application_name) -> None:
+    """
+    Application is not running function to be used by behave feature files.
+    """
+
     application = get_application(context, application_name)
     if application.is_running():
         application.wait_before_app_closes(15)
 
 
 @step('Application "{application_name}" is running')
-def application_is_running(context, application_name):
+def application_is_running(context, application_name) -> None:
+    """
+    Application is running function to be used by behave feature files.
+    """
+
     application = get_application(context, application_name)
     application.already_running()
     if not application.is_running():
@@ -306,15 +413,24 @@ def application_is_running(context, application_name):
 
 
 @step('Run and save command output: "{command}"')
-def run_and_save(context, command):
+def run_and_save(context, command) -> None:
     """
     Run a shell command and store its returncode, stdour and stderr to context.
 
+    :param context: Holds contextual information during the running of tests.
+    :type context: <behave.runner.Context>
+
     :type command: str
     :param command: Command line to be executed and result stored.
     """
 
-    process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True, encoding="utf-8")
+    process = subprocess.Popen(
+        command,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
+        shell=True,
+        encoding="utf-8",
+    )
     try:
         stdout, stderr = process.communicate(timeout=5)
     except subprocess.TimeoutExpired:
@@ -328,10 +444,13 @@ def run_and_save(context, command):
 
 
 @step('Last command output "{operand}" "{expected_output}"')
-def verify_content_in_output(context, operand, expected_output):
+def verify_content_in_output(context, operand, expected_output) -> None:
     """
     Verify that the result of last command has a certain data as a result.
 
+    :param context: Holds contextual information during the running of tests.
+    :type context: <behave.runner.Context>
+
     :type operand: str
     :param operand: String specifying what operation to do.
 
@@ -371,7 +490,7 @@ def verify_content_in_output(context, operand, expected_output):
         ))
 
     if operand == "does not contain":
-        assert not expected_output in command_output, "".join((
+        assert expected_output not in command_output, "".join((
             f"\nOutput should not contain: '{expected_output}'",
             f"\nBut it does: '{command_output}'"
         ))
@@ -402,10 +521,13 @@ def verify_content_in_output(context, operand, expected_output):
 
 
 @step('Return code of last command output "{operand}" "{expected_return_code}"')
-def verify_return_code_of_command(context, operand, expected_return_code):
+def verify_return_code_of_command(context, operand, expected_return_code) -> None:
     """
     Verify the return code of last command.
 
+    :param context: Holds contextual information during the running of tests.
+    :type context: <behave.runner.Context>
+
     :type operand: str
     :param operand: String specifying what operation to do.
 
@@ -439,32 +561,101 @@ def verify_return_code_of_command(context, operand, expected_return_code):
 
 
 @step('Type text: "{text}"')
-def type_text(context, text):
+def type_text(context, text) -> None:  # pylint: disable=unused-argument
+    """
+    Typing text function to be used by behave feature files.
+
+    :param context: Holds contextual information during the running of tests.
+    :type context: <behave.runner.Context>
+
+    :param text: Text to type.
+    :type text: str
+    """
+
     typeText(text)
 
 
 @step('Press key: "{key_name}"')
-def press_key(context, key_name):
+def press_key(context, key_name) -> None:  # pylint: disable=unused-argument
+    """
+    Press key function to be used by behave feature files.
+
+    :param context: Holds contextual information during the running of tests.
+    :type context: <behave.runner.Context>
+
+    :param key_name: Key to press.
+    :type key_name: str
+    """
+
     pressKey(key_name)
 
 
 @step('Key combo: "{combo_name}"')
-def key_combo(context, combo_name):
+def key_combo(context, combo_name) -> None:  # pylint: disable=unused-argument
+    """
+    Key combo function to be used by behave feature files.
+
+    :param context: Holds contextual information during the running of tests.
+    :type context: <behave.runner.Context>
+
+    :param combo_name: Combo to execute.
+    :type combo_name: str
+    """
+
     keyCombo(combo_name)
 
 
 @step('Wait {number} second before action')
 @step('Wait {number} seconds before action')
-def wait_up(context, number):
+def wait_up(context, number) -> None:  # pylint: disable=unused-argument
+    """
+    Sleep function to be used by behave feature files.
+
+    :param context: Holds contextual information during the running of tests.
+    :type context: <behave.runner.Context>
+
+    :param number: Numeric value for sleep.
+    :type number: str
+    """
+
     sleep(int(number))
 
 
 @step('Move mouse to: x: "{position_x}", y: "{position_y}"')
-def absolutie_motion(context, position_x, position_y):
+def absolutie_motion(context, position_x, position_y) -> None:  # pylint: disable=unused-argument
+    """
+    Move mouse to coordinates function to be used by behave feature files.
+
+    :param context: Holds contextual information during the running of tests.
+    :type context: <behave.runner.Context>
+
+    :param position_x: Position X to move mouse
+    :type position_x: str
+
+    :param position_y: Position Y to move mouse to.
+    :type position_y: str
+    """
+
     absoluteMotion(int(position_x), int(position_y))
 
 
 @step('{button} click on: x: "{position_x}", y: "{position_y}"')
-def click_on_position(context, button, position_x, position_y):
-    buttons = dict(Left=1, Middle=2, Right=3)
+def click_on_position(context, button, position_x, position_y) -> None:  # pylint: disable=unused-argument
+    """
+    Mouse click to coordinates function to be used by behave feature files.
+
+    :param context: Holds contextual information during the running of tests.
+    :type context: <behave.runner.Context>
+
+    :param button: Mouse button to press.
+    :type button: str
+
+    :param position_x: Position X to click.
+    :type position_x: str
+
+    :param position_y: Position Y to click.
+    :type position_y: str
+    """
+
+    buttons = {"Left": 1, "Middle": 2, "Right": 3}
     click(int(position_x), int(position_y), buttons[button])
