@@ -1,11 +1,18 @@
 #!/usr/bin/env python3
+"""
+This file provides online accounts functions.
+"""
+
 import os
 import sys
 import traceback
 from time import sleep
 import yaml
-from behave import step
-from dogtail.rawinput import pressKey, typeText
+
+from behave import step  # pylint: disable=no-name-in-module
+
+from dogtail.rawinput import pressKey, typeText  # pylint: disable=import-error
+
 from qecore.utility import get_application, run
 
 
@@ -16,10 +23,10 @@ from qecore.utility import get_application, run
 
 class Accounts:
     """
-    **With this class all accounts are added and removed.**
+    With this class all accounts are added and removed.
     """
 
-    def __init__(self, context):
+    def __init__(self, context) -> None:
         """
         Initiate Accounts instance.
 
@@ -31,20 +38,20 @@ class Accounts:
         self.account_data = None
 
         try:
-            # if its defined in environment.
+            # If it is defined in environment.
             self.application = get_application(context, "gnome-control-center")
-        except Exception:
-            # if its not defined in environment.
+        except Exception:  # pylint: disable=broad-except
+            # If it is not defined in environment.
             self.application = context.sandbox.get_application(
                 name="gnome-control-center", desktop_file_name="gnome-control-center"
             )
 
-    def remove_all_accounts(self):
+    def remove_all_accounts(self) -> None:
         """
         Remove all accounts added via gnome-online-accounts.
         """
 
-        self.context.sandbox._detect_keyring()
+        self.context.sandbox._detect_keyring()  # pylint: disable=protected-access
         self.application.start_via_command("gnome-control-center online-accounts")
 
         target = self.application.instance.child("Connect to your data in the cloud")
@@ -59,7 +66,7 @@ class Accounts:
 
         self.application.close_via_shortcut()
 
-    def remove_account(self, account_name):
+    def remove_account(self, account_name) -> None:
         """
         Remove single account added via gnome-online-accounts.
 
@@ -67,7 +74,7 @@ class Accounts:
         :param account_name: Name of the account.
         """
 
-        self.context.sandbox._detect_keyring()
+        self.context.sandbox._detect_keyring()  # pylint: disable=protected-access
         self.application.start_via_command("gnome-control-center online-accounts")
 
         target = self.application.instance.child("Connect to your data in the cloud")
@@ -79,12 +86,12 @@ class Accounts:
         try:
             existing_accounts[account_name].click()
             self.application.instance.child("Remove Account").click()
-        except Exception as error:
+        except Exception as error:  # pylint: disable=broad-except
             print(f"\nAccount '{error}' was not detected or was already removed.\n")
 
         self.application.close_via_shortcut()
 
-    def account_exists(self, account_name):
+    def account_exists(self, account_name) -> bool:
         """
         Found out if there is an account added via gnome-online-accounts.
 
@@ -108,7 +115,7 @@ class Accounts:
 
     def add_account(
         self, account_id, login=None, password=None, server=None, yaml_file=None
-    ):
+    ) -> None:
         """
         Add account to the gnome-online-accounts.
 
@@ -128,7 +135,7 @@ class Accounts:
         :param yaml_file: Location of yaml file.
         """
 
-        self.context.sandbox._detect_keyring()
+        self.context.sandbox._detect_keyring()  # pylint: disable=protected-access
         self.account_data = AccountData(
             account_id,
             login=login,
@@ -154,20 +161,27 @@ class Accounts:
 
         if account_name == "Google":
             add_google_account(self.context, self.account_data, account_login_dialog)
+
         if account_name == "Nextcloud":
             add_nextcloud_account(self.context, self.account_data, account_login_dialog)
+
         if account_name == "Facebook":
             add_facebook_account(self.context, self.account_data, account_login_dialog)
+
         if account_name == "Microsoft":
             add_microsoft_account(self.context, self.account_data, account_login_dialog)
+
         if account_name == "Flickr":
             add_flickr_account(self.context, self.account_data, account_login_dialog)
+
         if account_name == "Pocket":
             add_pocket_account(self.context, self.account_data, account_login_dialog)
+
         if account_name == "Foursquare":
             add_foursquare_account(
                 self.context, self.account_data, account_login_dialog
             )
+
         if account_name == "Microsoft Exchange":
             add_microsoft_exchange_account(
                 self.context, self.account_data, account_login_dialog
@@ -182,7 +196,7 @@ class Accounts:
 
 class AccountData:
     """
-    **With this class we keep and get all data about accounts.**
+    With this class we keep and get all data about accounts.
     """
 
     def __init__(
@@ -193,7 +207,7 @@ class AccountData:
         server=None,
         yaml_data=None,
         yaml_file=None,
-    ):
+    ) -> None:
         """
         Account class.
 
@@ -238,7 +252,7 @@ class AccountData:
             self.get_account_data()
             self.parse_account_data()
 
-    def get_account_data(self, yaml_file="online_accounts.yaml"):
+    def get_account_data(self, yaml_file="online_accounts.yaml") -> None:
         """
         Load yaml data to the class attribute.
 
@@ -267,7 +281,7 @@ class AccountData:
                     )
                 )
 
-    def parse_account_data(self):
+    def parse_account_data(self) -> None:
         """
         Parse the data from the yaml data.
         Retrieves name, login, password, server.
@@ -275,35 +289,35 @@ class AccountData:
 
         try:
             self.name = self.yaml_data[self.account_id]["name"]
-        except KeyError:
+        except KeyError as error:
             raise KeyError(
                 f"Name for account '{self.account_id}' is expected, but was not provided."
-            )
+            ) from error
 
         try:
             self.login = self.yaml_data[self.account_id]["login"]
-        except KeyError:
+        except KeyError as error:
             raise KeyError(
                 f"Login for account '{self.account_id}' is expected, but was not provided."
-            )
+            ) from error
 
         try:
             self.password = self.yaml_data[self.account_id]["password"]
-        except KeyError:
+        except KeyError as error:
             raise KeyError(
                 f"Password for account '{self.account_id}' is expected, but was not provided."
-            )
+            ) from error
 
         try:
             self.server = self.yaml_data[self.account_id]["server"]
-        except KeyError:
-            if self.name == "Nextcloud" or self.name == "Microsoft Exchange":
+        except KeyError as error:
+            if self.name in ("Nextcloud", "Microsoft Exchange"):
                 raise KeyError(
                     f"Server for account '{self.account_id}' is expected, but was not provided."
-                )
+                ) from error
 
 
-def wait_until_progress_bar_dissapears_in(account_login_dialog):
+def wait_until_progress_bar_dissapears_in(account_login_dialog) -> None:
     """
     Waiting until the progress bar from the gnome-online-accounts widget disappears.
 
@@ -318,7 +332,7 @@ def wait_until_progress_bar_dissapears_in(account_login_dialog):
         sleep(0.2)
 
 
-def add_google_account(context, data, account_login_dialog):
+def add_google_account(context, data, account_login_dialog) -> None:
     """
     Adding a Google account to the gnome-online-accounts.
 
@@ -366,13 +380,13 @@ def add_google_account(context, data, account_login_dialog):
         for _ in range(10):
             if account_login_dialog.child("Allow", retry=False).showing:
                 sleep(1)
-    except Exception:
+    except Exception:  # pylint: disable=broad-except
         pass
 
-    context.sandbox._detect_keyring()
+    context.sandbox._detect_keyring()  # pylint: disable=protected-access
 
 
-def add_nextcloud_account(context, data, account_login_dialog):
+def add_nextcloud_account(context, data, account_login_dialog) -> None:
     """
     Adding a Nextcloud account to the gnome-online-accounts.
 
@@ -403,13 +417,13 @@ def add_nextcloud_account(context, data, account_login_dialog):
 
     try:
         account_login_dialog.child("Ignore").click()
-    except Exception:
+    except Exception:  # pylint: disable=broad-except
         pass
 
-    context.sandbox._detect_keyring()
+    context.sandbox._detect_keyring()  # pylint: disable=protected-access
 
 
-def add_facebook_account(context, data, account_login_dialog):
+def add_facebook_account(context, data, account_login_dialog) -> None:
     """
     Adding a Facebook account to the gnome-online-accounts.
 
@@ -441,10 +455,10 @@ def add_facebook_account(context, data, account_login_dialog):
     )
     continue_button.click()
 
-    context.sandbox._detect_keyring()
+    context.sandbox._detect_keyring()  # pylint: disable=protected-access
 
 
-def add_microsoft_account(context, data, account_login_dialog):
+def add_microsoft_account(context, data, account_login_dialog) -> None:
     """
     Adding a Microsoft account to the gnome-online-accounts.
 
@@ -476,10 +490,10 @@ def add_microsoft_account(context, data, account_login_dialog):
     sign_in = account_login_dialog.child("Sign in")
     sign_in.click()
 
-    context.sandbox._detect_keyring()
+    context.sandbox._detect_keyring()  # pylint: disable=protected-access
 
 
-def add_flickr_account(context, data, account_login_dialog):
+def add_flickr_account(context, data, account_login_dialog) -> None:
     """
     Adding a Flickr account to the gnome-online-accounts.
 
@@ -507,7 +521,7 @@ def add_flickr_account(context, data, account_login_dialog):
         wait_until_progress_bar_dissapears_in(account_login_dialog)
         next_button = account_login_dialog.child("Next", retry=False)
         next_button.click()
-    except Exception:
+    except Exception:  # pylint: disable=broad-except
         pass
 
     wait_until_progress_bar_dissapears_in(account_login_dialog)
@@ -524,10 +538,10 @@ def add_flickr_account(context, data, account_login_dialog):
     pressKey("PageDown")
     authorize_button.click()
 
-    context.sandbox._detect_keyring()
+    context.sandbox._detect_keyring()  # pylint: disable=protected-access
 
 
-def add_pocket_account(context, data, account_login_dialog):
+def add_pocket_account(context, data, account_login_dialog) -> None:
     """
     Adding a Pocket account to the gnome-online-accounts.
 
@@ -559,7 +573,7 @@ def add_pocket_account(context, data, account_login_dialog):
             retry=False,
         )
         pressKey("PageDown")
-    except Exception:
+    except Exception:  # pylint: disable=broad-except
         email_entry = account_login_dialog.child("Email", "entry")
         while not email_entry.sensitive:
             sleep(0.2)
@@ -581,7 +595,7 @@ def add_pocket_account(context, data, account_login_dialog):
             break
         sleep(1)
         found_node.click()
-    except Exception:
+    except Exception:  # pylint: disable=broad-except
         pass
 
     try:
@@ -591,13 +605,13 @@ def add_pocket_account(context, data, account_login_dialog):
             break
         sleep(1)
         found_node.click()
-    except Exception:
+    except Exception:  # pylint: disable=broad-except
         pass
 
-    context.sandbox._detect_keyring()
+    context.sandbox._detect_keyring()  # pylint: disable=protected-access
 
 
-def add_foursquare_account(context, data, account_login_dialog):
+def add_foursquare_account(context, data, account_login_dialog) -> None:
     """
     Adding a FourSquare account to the gnome-online-accounts.
 
@@ -627,10 +641,10 @@ def add_foursquare_account(context, data, account_login_dialog):
     log_in_and_allow_button = account_login_dialog.child("Log in and allow")
     log_in_and_allow_button.click()
 
-    context.sandbox._detect_keyring()
+    context.sandbox._detect_keyring()  # pylint: disable=protected-access
 
 
-def add_microsoft_exchange_account(context, data, account_login_dialog):
+def add_microsoft_exchange_account(context, data, account_login_dialog) -> None:
     """
     Adding a Microsoft Exchange account to the gnome-online-accounts.
 
@@ -672,13 +686,15 @@ def add_microsoft_exchange_account(context, data, account_login_dialog):
         sleep(0.2)
     ignore_button.click()
 
-    context.sandbox._detect_keyring()
+    context.sandbox._detect_keyring()  # pylint: disable=protected-access
 
 
 @step('Add "{account_name}" account')
 @step('Add "{account_name}" account from file "{yaml_file}"')
 @step('Add "{account_name}" account with login "{login}" and password "{password}"')
-def add_account(context, account_name, login=None, password=None, yaml_file=None):
+def add_account(
+    context, account_name, login=None, password=None, yaml_file=None
+) -> None:
     """
     Function with behave step decorators::
 
@@ -693,8 +709,8 @@ def add_account(context, account_name, login=None, password=None, yaml_file=None
             account_name, login=login, password=password, yaml_file=yaml_file
         )
     except KeyError as error:
-        raise KeyError(error)
-    except Exception:
+        raise KeyError(error) from error
+    except Exception:  # pylint: disable=broad-except
         run(f"rm -rf {os.path.expanduser('~')}/.local/share/webkitgtk/*")
         accounts.add_account(
             account_name, login=login, password=password, yaml_file=yaml_file
@@ -702,7 +718,7 @@ def add_account(context, account_name, login=None, password=None, yaml_file=None
 
 
 @step("Remove all accounts")
-def remove_accounts(context):
+def remove_accounts(context) -> None:
     """
     Function with behave step decorator::
 
@@ -712,5 +728,5 @@ def remove_accounts(context):
     accounts = Accounts(context)
     try:
         accounts.remove_all_accounts()
-    except Exception:
+    except Exception:  # pylint: disable=broad-except
         accounts.remove_all_accounts()
