@@ -652,8 +652,10 @@ class TestSandbox:
 
                 if "gnome-shell" not in [x.name for x in root.applications()]:
                     log.debug(
-                        "_wait_until_shell_becomes_responsive: ",
-                        "gnome-shell not detected in a11y root yet.",
+                        "".join((
+                            "_wait_until_shell_becomes_responsive: ",
+                            "gnome-shell not detected in a11y root yet.",
+                        ))
                     )
                     sleep(0.5)
                 else:
@@ -693,8 +695,11 @@ class TestSandbox:
         self.session_display = run("echo $DISPLAY").strip("\n")
         if not self.session_display:
             log.debug(
-                "_retrieve_session_data: session display is not set - retrieve from ",
-                "qecore_get_active_display",
+                "".join((
+                    "_retrieve_session_data: session display is not set - retrieve from ",
+                    "qecore_get_active_display",
+                ))
+
             )
 
             self.session_display = run("qecore_get_active_display").strip("\n")
