@@ -1,4 +1,8 @@
 #!/usr/bin/env python3
+"""
+Utility file that provides various functions.
+"""
+
 import os
 import sys
 import traceback
@@ -7,11 +11,18 @@ from functools import partial
 from subprocess import STDOUT, CalledProcessError, check_output
 from time import sleep, time
 from types import FunctionType
+from typing import TypeVar
+
+# We do this just to satisfy the typing hint but without the need to import entire class.
+gi_repository_Atspi_Accessible = TypeVar(  # pylint: disable=invalid-name
+    "gi_repository_Atspi_Accessible"
+)
+Application = TypeVar("Application")
 
 QE_DEVELOPMENT = not os.path.isdir("/mnt/tests/")
 
 
-def get_application(context, application):
+def get_application(context, application) -> Application:
     """
     Get Application class instance of an application, based upon given name.
 
@@ -63,7 +74,9 @@ def get_application(context, application):
     return app_class_to_return
 
 
-def get_application_root(context, application):
+def get_application_root(  # pylint: disable=unused-argument
+    context, application
+) -> gi_repository_Atspi_Accessible:
     """
     Get Accessibility object of an application, based upon given name.
 
@@ -80,33 +93,51 @@ def get_application_root(context, application):
 
         Do **NOT** call this by yourself. This function is called by :mod:`common_steps`.
     """
-    from dogtail.tree import root
+
+    from dogtail.tree import (  # pylint: disable=import-error,import-outside-toplevel
+        root,
+    )
 
     try:
         root_to_return = root.application(application)
-    except Exception:
+    except Exception as error:  # pylint: disable=broad-except
         traceback.print_exc(file=sys.stdout)
-        assert False, "".join(
-            (
-                "Application was not found in accessibility. Check your environment or feature file!",
+        raise UserWarning(
+            "".join(
+                (
+                    "Application was not found in accessibility. ",
+                    "Check your environment or feature file!",
+                )
             )
-        )
+        ) from error
 
     return root_to_return
 
 
-def run(command, verbose=False):
+def run(command) -> str:
     """
     Execute a command and get output.
 
     :type command: str
     :param command: Command to be executed.
 
-    :type verbose: bool
-    :param verbose: Boolean value for verbose option.
-
     :rtype: str
-    :return: Return string value of command output.
+    :return: Return string value of command output or exception error output.
+    """
+
+    try:
+        output = check_output(command, shell=True, stderr=STDOUT, encoding="utf-8")
+        return output
+    except CalledProcessError as error:
+        return error.output
+
+
+def run_verbose(command) -> tuple:
+    """
+    Execute a command and get output in verbose format.
+
+    :type command: str
+    :param command: Command to be executed.
 
     :rtype: list
     :return: Return list with following format (output, return code, exception).
@@ -114,9 +145,9 @@ def run(command, verbose=False):
 
     try:
         output = check_output(command, shell=True, stderr=STDOUT, encoding="utf-8")
-        return output if not verbose else (output, 0, None)
+        return (output, 0, None)
     except CalledProcessError as error:
-        return error.output if not verbose else (error.output, error.returncode, error)
+        return (error.output, error.returncode, error)
 
 
 def run_embed(context, command, *a, **kw):
@@ -140,10 +171,10 @@ def run_embed(context, command, *a, **kw):
         )
         return_code = 0
         error = None
-    except CalledProcessError as error:
-        output = error.output
-        return_code = error.returncode
-        error = error
+    except CalledProcessError as process_error:
+        output = process_error.output
+        return_code = process_error.returncode
+        error = process_error
 
     context.embed("text/plain", f"$?={return_code}", caption=f"{command} result")
     context.embed("text/plain", output, caption=f"{command} output")
@@ -170,7 +201,9 @@ def overview_action(action="hide") -> None:
         )
     )
 
-    from dogtail.tree import root
+    from dogtail.tree import (  # pylint: disable=import-error,import-outside-toplevel
+        root,
+    )
 
     gnome_shell = root.application("gnome-shell")
 
@@ -179,7 +212,9 @@ def overview_action(action="hide") -> None:
     )
 
     if len(activities_label) == 1:
-        from dogtail.predicate import GenericPredicate
+        from dogtail.predicate import (  # pylint: disable=import-error,import-outside-toplevel
+            GenericPredicate,
+        )
 
         # Find Ancestor unfortunatelly takes only Predicates not lambdas alone, \
         # will use it since implementing it here would be too long.
@@ -202,7 +237,9 @@ def overview_action(action="hide") -> None:
 
 
 # behave-common-steps leftover.
-def wait_until(tested, element=None, timeout=30, period=0.25, params_in_list=False):
+def wait_until(
+    tested, element=None, timeout=30, period=0.25, params_in_list=False
+) -> bool:
     """
     This function keeps running lambda with specified params until the
     result is True or timeout is reached. Instead of lambda, Boolean variable
@@ -221,7 +258,6 @@ def wait_until(tested, element=None, timeout=30, period=0.25, params_in_list=Fal
 
         >>> wait_until(dialog.dead)
         Wait until the dialog is dead
-
     """
 
     if isinstance(tested, bool):
@@ -280,8 +316,10 @@ class HoldKey:
 
     """
 
-    def __init__(self, key_name):
-        from dogtail.rawinput import holdKey
+    def __init__(self, key_name) -> None:
+        from dogtail.rawinput import (  # pylint: disable=import-error,import-outside-toplevel
+            holdKey,
+        )
 
         self.key_name = key_name
         holdKey(self.key_name)
@@ -289,8 +327,10 @@ class HoldKey:
     def __enter__(self):
         return self
 
-    def __exit__(self, my_type, value, trace):
-        from dogtail.rawinput import releaseKey
+    def __exit__(self, my_type, value, trace) -> None:
+        from dogtail.rawinput import (  # pylint: disable=import-error,import-outside-toplevel
+            releaseKey,
+        )
 
         releaseKey(self.key_name)
 
@@ -309,17 +349,33 @@ class Tuple(tuple):
     def __rmul__(self, other):
         return Tuple(other * x for x in self)
 
-    def __eq__(self, other):
+    def __eq__(self, other) -> bool:
         return all(x == y for x, y in zip(self, other))
 
-    def __lt__(self, other):
+    def __lt__(self, other) -> bool:
         return self[0] < other[0] or self[1] < other[1]
 
-    def __gt__(self, other):
+    def __gt__(self, other) -> bool:
         return self[0] > other[0] or self[1] > other[1]
 
 
-def validate_command(command):
+def get_center(node) -> Tuple:
+    """
+    Simple utility to get the center of the node.
+
+    :type node: <dogtail.tree.Node>
+    :param node: Node passed to the function.
+
+    :rtype: Tuple
+    :return: Tuple with coordinates of the center of a Node.
+    """
+
+    return Tuple(
+        (node.position[0] + node.size[0] / 2, node.position[1] + node.size[1] / 2)
+    )
+
+
+def validate_command(command) -> str:
     """
     Simple utility to try and escape any character that is not alpha character.
 
@@ -353,14 +409,14 @@ def verify_path(template_path):
     try:
         assert os.path.isfile(template_path)
     except Exception as error:
-        assert False, f"Desired file was not found: {error}"
+        raise UserWarning(f"Desired file was not found: {error}") from error
     return template_path
 
 
 SPACER = " "
 
 
-def plain_dump(node):
+def plain_dump(node) -> None:
     """
     Simple attempt to get more information from a11y tree.
 
@@ -368,12 +424,12 @@ def plain_dump(node):
     :param node: Accessibility node.
     """
 
-    def crawl(node, depth):
+    def crawl(node, depth) -> None:
         dump(node, depth)
         for child in node.children:
             crawl(child, depth + 1)
 
-    def dump_std_out(item, depth):
+    def dump_std_out(item, depth) -> None:
         print(
             SPACER * depth
             + str(item)
